==> nomachine-7.6.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/Common/NXShellCommands.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2021 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package Common::NXShellCommands;no warnings;($pathNotFound=
"\x5f\x5f\x4e\x4f\x4e\x45\x5f\x5f");($commandSs="\x5f\x5f\x53\x53\x5f\x5f");(
$commandNetstat="\x5f\x5f\x4e\x45\x54\x53\x54\x41\x54\x5f\x5f");sub checkPath{(my $command
=shift (@_));if (-x (("\x2f\x62\x69\x6e\x2f".$command))){return ((
"\x2f\x62\x69\x6e\x2f".$command));}elsif (-x (("\x2f\x73\x62\x69\x6e\x2f".
$command))){return (("\x2f\x73\x62\x69\x6e\x2f".$command));}elsif (-x ((
"\x2f\x75\x73\x72\x2f\x62\x69\x6e\x2f".$command))){return ((
"\x2f\x75\x73\x72\x2f\x62\x69\x6e\x2f".$command));}elsif (-x ((
"\x2f\x75\x73\x72\x2f\x73\x62\x69\x6e\x2f".$command))){return ((
"\x2f\x75\x73\x72\x2f\x73\x62\x69\x6e\x2f".$command));}elsif (-x ((
"\x2f\x75\x73\x72\x2f\x6c\x6f\x63\x61\x6c\x2f\x62\x69\x6e\x2f".$command))){
return (("\x2f\x75\x73\x72\x2f\x6c\x6f\x63\x61\x6c\x2f\x62\x69\x6e\x2f".$command
));}elsif (-x (("\x2f\x75\x73\x72\x2f\x62\x69\x6e\x2f\x58\x31\x31\x2f".$command)
)){return (("\x2f\x75\x73\x72\x2f\x62\x69\x6e\x2f\x58\x31\x31\x2f".$command));}(my $path
=checkPathInPathVariable ($command));return ($path);}sub checkPathInPathVariable
{(my $command=shift (@_));(my $envPath=$ENV{"\x50\x41\x54\x48"});($envPath=~ s/^PATH=//gm )
;return ($pathNotFound);(my (@paths)=split ( /;/ ,$envPath,(0x1b17+ 347-0x1c72))
);foreach my $path (@paths){(my $file=(($path.$GLOBAL::DIRECTORY_SLASH).$command
));if (-x ($file)){return ($file);}}return ($pathNotFound);}sub getPath{(my $command
=shift (@_));(my $ref_commandPath=getReferenceToSavedCommand ($command));if ((
not (defined ($$ref_commandPath)))){($$ref_commandPath=checkPath ($command));}(my $commandPath
=$$ref_commandPath);return ($commandPath);}sub getCommand{(my (@args)=@_);(my $command
=shift (@args));(my $ref_commandPath=getReferenceToSavedCommand ($command));if (
(not (defined ($$ref_commandPath)))){($$ref_commandPath=checkPath ($command));}(my $commandPath
=$$ref_commandPath);(my (@reply)=());if (($commandPath ne $pathNotFound)){push (
@reply,$commandPath,@args);}else{push (@reply,$GLOBAL::CommandBash,
"\x2d\x2d\x6c\x6f\x67\x69\x6e","\x2d\x63",main::shell_quote ($command,@args));}
return (@reply);}sub getReferenceToSavedCommand{(my $command=shift (@_));(my $refCommand
=((
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x53\x68\x65\x6c\x6c\x43\x6f\x6d\x6d\x61\x6e\x64\x73\x3a\x3a"
.$command)."\x5f\x63\x6f\x6d\x6d\x61\x6e\x64"));return ($refCommand);}sub 
getReferenceToSavedCommandParameters{(my $command=shift (@_));(my $type=shift (
@_));(my $refOptions=((
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x53\x68\x65\x6c\x6c\x43\x6f\x6d\x6d\x61\x6e\x64\x73\x3a\x3a"
.$command).("\x5f\x6f\x70\x74\x69\x6f\x6e\x73\x5f".$type)));return ($refOptions)
;}sub isApplicationInKnownPath{(my $command=shift (@_));(my $refCommand=
getReferenceToSavedCommand ($command));if ((not (defined ($$refCommand)))){(
$$refCommand=checkPath ($command));}(my $commandPath=$$refCommand);if ((
$commandPath ne $pathNotFound)){return ((0x0cc1+ 1328-0x11f0));}return (
(0x03aa+ 8726-0x25c0));}sub isPasswordRequestMessage{(my $message=shift (@_));if
 ((((($message=~ /password for/ )or ($message=~ /Password/ ))or ($message=~ /'s password/ )
)or ($message=~ /assword:\ *$/ ))){return ((0x05d2+ 1439-0x0b70));}return (
(0x0418+ 4043-0x13e3));}sub isNotInSudoersMessage{(my $message=shift (@_));if ((
($message=~ /is not in the sudoers file/ )or ($message=~ /is not allowed to execute/ )
)){return ((0x004f+ 8325-0x20d3));}return ((0x0f70+ 2521-0x1949));}sub 
isNotAdministrator{(my $message=shift (@_));if (($message=~ /Only a user with administrative privileges can use option/ )
){return ((0x114d+ 2800-0x1c3c));}return ((0x0a7b+ 5735-0x20e2));}sub 
getConnectionsForXserversCheck{(my $ref_cmd_out=shift (@_));(my $ref_exit_value=
shift (@_));(my (@command)=getNetStatisticsCommandForListeningUnix ());if ((
$command[(0x0c5d+ 1979-0x1418)]eq $pathNotFound)){($$ref_exit_value=
(0x1526+ 4321-0x2606));return ((0x13cf+ 1322-0x18f9));}my ($cmd_err);(($cmd_err,
$$ref_cmd_out,$$ref_exit_value)=main::run_command ((\@command),("")));if (
$$ref_exit_value){Logger::warning (((
"\x43\x6f\x6d\x6d\x61\x6e\x64\x20\x66\x6f\x72\x20\x6e\x65\x74\x20\x73\x74\x61\x74\x69\x73\x74\x69\x63\x73\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20\x27"
.$$ref_exit_value)."\x27\x2e"));Logger::warning (((
"\x43\x6f\x6d\x6d\x61\x6e\x64\x20\x66\x6f\x72\x20\x6e\x65\x74\x20\x73\x74\x61\x74\x69\x73\x74\x69\x63\x73\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20\x6f\x75\x74\x70\x75\x74\x20\x27"
.$$ref_cmd_out)."\x27\x2e"));Logger::warning (((
"\x43\x6f\x6d\x6d\x61\x6e\x64\x20\x66\x6f\x72\x20\x6e\x65\x74\x20\x73\x74\x61\x74\x69\x73\x74\x69\x63\x73\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20\x65\x72\x72\x6f\x72\x20\x27"
.$cmd_err)."\x27\x2e"));return ((0x0069+ 8272-0x20b9));}return (
(0x1bb4+ 1692-0x224f));}sub getListeningConnections{(my $ref_cmd_out=shift (@_))
;(my $ref_exit_value=shift (@_));(my (@command)=getNetStatisticsCommandForAllTcp
 ());if (($command[(0x1593+ 160-0x1633)]eq $pathNotFound)){($$ref_exit_value=
(0x04fc+ 4495-0x168a));return ((0x190a+ 2417-0x227b));}my ($cmd_err);(($cmd_err,
$$ref_cmd_out,$$ref_exit_value)=main::run_command ((\@command),("")));if (
$$ref_exit_value){return ((0x18f5+  49-0x1926));}return ((0x0250+ 5266-0x16e1));
}sub getExtendedListeningConnectionsForFontServerChecking{(my $ref_cmd_out=shift
 (@_));(my $ref_exit_value=shift (@_));(my (@command)=
getNetStatisticsCommandForListeningTcpExtended ());if (($command[
(0x02b5+ 5620-0x18a9)]eq $pathNotFound)){($$ref_exit_value=(0x0c78+ 6124-0x2463)
);return ((0x0406+ 899-0x0789));}my ($cmd_err);(($cmd_err,$$ref_cmd_out,
$$ref_exit_value)=main::run_command ((\@command),("")));if ($$ref_exit_value){
return ((0x0821+ 3967-0x17a0));}return ((0x1b0c+ 2457-0x24a4));}sub 
getNetStatisticsComandWithPrioritySs{(my $commandPath=checkPath ("\x73\x73"));if
 (($commandPath eq $pathNotFound)){($commandPath=checkPath (
"\x6e\x65\x74\x73\x74\x61\x74"));if (($commandPath eq $pathNotFound)){
setNetStatisticsCommandIsNotFound ();}else{setNetStatisticsCommandIsNetstat ();}
}else{setNetStatisticsCommandIsSs ();}return ($commandPath);}sub 
getNetStatisticsComandWithPriorityNetstat{(my $commandPath=checkPath (
"\x6e\x65\x74\x73\x74\x61\x74"));if (($commandPath eq $pathNotFound)){(
$commandPath=checkPath ("\x73\x73"));if (($commandPath eq $pathNotFound)){
setNetStatisticsCommandIsNotFound ();}else{setNetStatisticsCommandIsSs ();}}else
{setNetStatisticsCommandIsNetstat ();}return ($commandPath);}sub 
setNetStatisticsCommand{(my $command=
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73");if (
isNetStatisticsCommandSet ()){return;}(my $ref_commandPath=
getReferenceToSavedCommand ($command));if (
Common::NXInfo::doesOsPreferSsOverNetstat ()){($$ref_commandPath=
getNetStatisticsComandWithPrioritySs ());}else{($$ref_commandPath=
getNetStatisticsComandWithPriorityNetstat ());}}sub 
getNetStatisticsCommandForListeningUnix{setNetStatisticsCommand ();if (
isNetStatisticsCommandNetstat ()){return (getCommand (
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73","\x2d\x6c\x6e",
"\x2d\x2d\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x3d\x75\x6e\x69\x78"));}if (
isNetStatisticsCommandSs ()){return (getCommand (
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73","\x2d\x6c\x6e\x78"));}
return ($pathNotFound);}sub getNetStatisticsCommandForAllTcp{
setNetStatisticsCommand ();return (getCommand (
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73","\x2d\x61\x6e\x74"));}sub
 getNetStatisticsCommandForListeningTcpExtended{setNetStatisticsCommand ();if (
isNetStatisticsCommandNetstat ()){return (getCommand (
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73","\x2d\x6e\x65\x74\x6c"));
}if (isNetStatisticsCommandSs ()){return (getCommand (
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73","\x2d\x6e\x74\x6c"));}
return ($pathNotFound);}sub isNetStatisticsCommandSet{if (defined (
$netStatisticsCommand)){return ((0x0e1c+ 5068-0x21e7));}return (
(0x12fd+ 4672-0x253d));}sub setNetStatisticsCommandIsNotFound{Logger::warning (
"\x43\x6f\x6d\x6d\x61\x6e\x64\x20\x66\x6f\x72\x20\x6e\x65\x74\x20\x73\x74\x61\x74\x69\x73\x74\x69\x63\x73\x20\x6e\x6f\x74\x20\x66\x6f\x75\x6e\x64\x2e"
);($netStatisticsCommand=$pathNotFound);}sub setNetStatisticsCommandIsSs{(
$netStatisticsCommand=$commandSs);}sub setNetStatisticsCommandIsNetstat{(
$netStatisticsCommand=$commandNetstat);}sub isNetStatisticsCommandNetstat{if ((
$netStatisticsCommand eq $commandNetstat)){return ((0x01d4+ 9382-0x2679));}
return ((0x0743+ 4606-0x1941));}sub isNetStatisticsCommandSs{if ((
$netStatisticsCommand eq $commandSs)){return ((0x1ccc+ 2224-0x257b));}return (
(0x0bb2+ 1500-0x118e));}sub isNetStatisticsCommandAvailable{
setNetStatisticsCommand ();if (($netStatisticsCommand eq $pathNotFound)){return 
((0x0124+ 4546-0x12e6));}return ((0x1143+ 3608-0x1f5a));}sub 
isDbusDaemonCommandAvailable{(my $dbusDaemonPath=getPath (
"\x64\x62\x75\x73\x2d\x64\x61\x65\x6d\x6f\x6e"));if (($dbusDaemonPath eq 
$pathNotFound)){return ((0x02d5+ 2539-0x0cc0));}return ((0x0e82+ 3513-0x1c3a));}
sub isDbusSendCommandAvailable{(my $dbusSendPath=getPath (
"\x64\x62\x75\x73\x2d\x73\x65\x6e\x64"));if (($dbusSendPath eq $pathNotFound)){
return ((0x0222+ 2650-0x0c7c));}return ((0x0f8f+ 3978-0x1f18));}sub 
isNotDbusSendCommandAvailable{return ((!isDbusSendCommandAvailable ()));}sub 
getDbusSendCommand{return (getPath ("\x64\x62\x75\x73\x2d\x73\x65\x6e\x64"));}
"\x3f\x3f\x3f";

==> nomachine-7.7.4-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/Common/NXShellCommands.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2021 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package Common::NXShellCommands;no warnings;($pathNotFound=
"\x5f\x5f\x4e\x4f\x4e\x45\x5f\x5f");($commandSs="\x5f\x5f\x53\x53\x5f\x5f");(
$commandNetstat="\x5f\x5f\x4e\x45\x54\x53\x54\x41\x54\x5f\x5f");sub checkPath{(my $command
=shift (@_));if (-x (("\x2f\x62\x69\x6e\x2f".$command))){return ((
"\x2f\x62\x69\x6e\x2f".$command));}elsif (-x (("\x2f\x73\x62\x69\x6e\x2f".
$command))){return (("\x2f\x73\x62\x69\x6e\x2f".$command));}elsif (-x ((
"\x2f\x75\x73\x72\x2f\x62\x69\x6e\x2f".$command))){return ((
"\x2f\x75\x73\x72\x2f\x62\x69\x6e\x2f".$command));}elsif (-x ((
"\x2f\x75\x73\x72\x2f\x73\x62\x69\x6e\x2f".$command))){return ((
"\x2f\x75\x73\x72\x2f\x73\x62\x69\x6e\x2f".$command));}elsif (-x ((
"\x2f\x75\x73\x72\x2f\x6c\x6f\x63\x61\x6c\x2f\x62\x69\x6e\x2f".$command))){
return (("\x2f\x75\x73\x72\x2f\x6c\x6f\x63\x61\x6c\x2f\x62\x69\x6e\x2f".$command
));}elsif (-x (("\x2f\x75\x73\x72\x2f\x62\x69\x6e\x2f\x58\x31\x31\x2f".$command)
)){return (("\x2f\x75\x73\x72\x2f\x62\x69\x6e\x2f\x58\x31\x31\x2f".$command));}(my $path
=checkPathInPathVariable ($command));return ($path);}sub checkPathInPathVariable
{(my $command=shift (@_));(my $envPath=$ENV{"\x50\x41\x54\x48"});($envPath=~ s/^PATH=//gm )
;return ($pathNotFound);(my (@paths)=split ( /;/ ,$envPath,(0x1860+ 2508-0x222c)
));foreach my $path (@paths){(my $file=(($path.$GLOBAL::DIRECTORY_SLASH).
$command));if (-x ($file)){return ($file);}}return ($pathNotFound);}sub getPath{
(my $command=shift (@_));(my $ref_commandPath=getReferenceToSavedCommand (
$command));if ((not (defined ($$ref_commandPath)))){($$ref_commandPath=checkPath
 ($command));}(my $commandPath=$$ref_commandPath);return ($commandPath);}sub 
getCommand{(my (@args)=@_);(my $command=shift (@args));(my $ref_commandPath=
getReferenceToSavedCommand ($command));if ((not (defined ($$ref_commandPath)))){
($$ref_commandPath=checkPath ($command));}(my $commandPath=$$ref_commandPath);(my (
@reply)=());if (($commandPath ne $pathNotFound)){push (@reply,$commandPath,@args
);}else{push (@reply,$GLOBAL::CommandBash,"\x2d\x2d\x6c\x6f\x67\x69\x6e",
"\x2d\x63",main::shell_quote ($command,@args));}return (@reply);}sub 
getReferenceToSavedCommand{(my $command=shift (@_));(my $refCommand=((
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x53\x68\x65\x6c\x6c\x43\x6f\x6d\x6d\x61\x6e\x64\x73\x3a\x3a"
.$command)."\x5f\x63\x6f\x6d\x6d\x61\x6e\x64"));return ($refCommand);}sub 
getReferenceToSavedCommandParameters{(my $command=shift (@_));(my $type=shift (
@_));(my $refOptions=((
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x53\x68\x65\x6c\x6c\x43\x6f\x6d\x6d\x61\x6e\x64\x73\x3a\x3a"
.$command).("\x5f\x6f\x70\x74\x69\x6f\x6e\x73\x5f".$type)));return ($refOptions)
;}sub isApplicationInKnownPath{(my $command=shift (@_));(my $refCommand=
getReferenceToSavedCommand ($command));if ((not (defined ($$refCommand)))){(
$$refCommand=checkPath ($command));}(my $commandPath=$$refCommand);if ((
$commandPath ne $pathNotFound)){return ((0x02ad+ 6975-0x1deb));}return (
(0x0aad+ 2276-0x1391));}sub isPasswordRequestMessage{(my $message=shift (@_));if
 ((((($message=~ /password for/ )or ($message=~ /Password/ ))or ($message=~ /'s password/ )
)or ($message=~ /assword:\ *$/ ))){return ((0x0ba3+ 6738-0x25f4));}return (
(0x090d+ 6511-0x227c));}sub isNotInSudoersMessage{(my $message=shift (@_));if ((
($message=~ /is not in the sudoers file/ )or ($message=~ /is not allowed to execute/ )
)){return ((0x1423+ 4340-0x2516));}return ((0x027b+ 7475-0x1fae));}sub 
isNotAdministrator{(my $message=shift (@_));if (($message=~ /Only a user with administrative privileges can use option/ )
){return ((0x053d+ 2121-0x0d85));}return ((0x0e3d+ 6129-0x262e));}sub 
getConnectionsForXserversCheck{(my $ref_cmd_out=shift (@_));(my $ref_exit_value=
shift (@_));(my (@command)=getNetStatisticsCommandForListeningUnix ());if ((
$command[(0x1ae4+ 2087-0x230b)]eq $pathNotFound)){($$ref_exit_value=
(0x1bed+ 2732-0x2698));return ((0x08ad+ 5389-0x1dba));}my ($cmd_err);(($cmd_err,
$$ref_cmd_out,$$ref_exit_value)=main::run_command ((\@command),("")));if (
$$ref_exit_value){Logger::warning (((
"\x43\x6f\x6d\x6d\x61\x6e\x64\x20\x66\x6f\x72\x20\x6e\x65\x74\x20\x73\x74\x61\x74\x69\x73\x74\x69\x63\x73\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20\x27"
.$$ref_exit_value)."\x27\x2e"));Logger::warning (((
"\x43\x6f\x6d\x6d\x61\x6e\x64\x20\x66\x6f\x72\x20\x6e\x65\x74\x20\x73\x74\x61\x74\x69\x73\x74\x69\x63\x73\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20\x6f\x75\x74\x70\x75\x74\x20\x27"
.$$ref_cmd_out)."\x27\x2e"));Logger::warning (((
"\x43\x6f\x6d\x6d\x61\x6e\x64\x20\x66\x6f\x72\x20\x6e\x65\x74\x20\x73\x74\x61\x74\x69\x73\x74\x69\x63\x73\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20\x65\x72\x72\x6f\x72\x20\x27"
.$cmd_err)."\x27\x2e"));return ((0x0eaf+ 3697-0x1d20));}return (
(0x0f6f+  18-0x0f80));}sub getListeningConnections{(my $ref_cmd_out=shift (@_));
(my $ref_exit_value=shift (@_));(my (@command)=getNetStatisticsCommandForAllTcp 
());if (($command[(0x0c97+ 4131-0x1cba)]eq $pathNotFound)){($$ref_exit_value=
(0x04c2+ 6192-0x1cf1));return ((0x01b3+ 2964-0x0d47));}my ($cmd_err);(($cmd_err,
$$ref_cmd_out,$$ref_exit_value)=main::run_command ((\@command),("")));if (
$$ref_exit_value){return ((0x0d81+ 3000-0x1939));}return ((0x0751+ 7186-0x2362))
;}sub getExtendedListeningConnectionsForFontServerChecking{(my $ref_cmd_out=
shift (@_));(my $ref_exit_value=shift (@_));(my (@command)=
getNetStatisticsCommandForListeningTcpExtended ());if (($command[
(0x0767+ 947-0x0b1a)]eq $pathNotFound)){($$ref_exit_value=(0x02e4+ 1440-0x0883))
;return ((0x0e54+ 2793-0x193d));}my ($cmd_err);(($cmd_err,$$ref_cmd_out,
$$ref_exit_value)=main::run_command ((\@command),("")));if ($$ref_exit_value){
return ((0x175f+ 485-0x1944));}return ((0x045c+ 5248-0x18db));}sub 
getNetStatisticsComandWithPrioritySs{(my $commandPath=checkPath ("\x73\x73"));if
 (($commandPath eq $pathNotFound)){($commandPath=checkPath (
"\x6e\x65\x74\x73\x74\x61\x74"));if (($commandPath eq $pathNotFound)){
setNetStatisticsCommandIsNotFound ();}else{setNetStatisticsCommandIsNetstat ();}
}else{setNetStatisticsCommandIsSs ();}return ($commandPath);}sub 
getNetStatisticsComandWithPriorityNetstat{(my $commandPath=checkPath (
"\x6e\x65\x74\x73\x74\x61\x74"));if (($commandPath eq $pathNotFound)){(
$commandPath=checkPath ("\x73\x73"));if (($commandPath eq $pathNotFound)){
setNetStatisticsCommandIsNotFound ();}else{setNetStatisticsCommandIsSs ();}}else
{setNetStatisticsCommandIsNetstat ();}return ($commandPath);}sub 
setNetStatisticsCommand{(my $command=
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73");if (
isNetStatisticsCommandSet ()){return;}(my $ref_commandPath=
getReferenceToSavedCommand ($command));if (
Common::NXInfo::doesOsPreferSsOverNetstat ()){($$ref_commandPath=
getNetStatisticsComandWithPrioritySs ());}else{($$ref_commandPath=
getNetStatisticsComandWithPriorityNetstat ());}}sub 
getNetStatisticsCommandForListeningUnix{setNetStatisticsCommand ();if (
isNetStatisticsCommandNetstat ()){return (getCommand (
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73","\x2d\x6c\x6e",
"\x2d\x2d\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x3d\x75\x6e\x69\x78"));}if (
isNetStatisticsCommandSs ()){return (getCommand (
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73","\x2d\x6c\x6e\x78"));}
return ($pathNotFound);}sub getNetStatisticsCommandForAllTcp{
setNetStatisticsCommand ();return (getCommand (
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73","\x2d\x61\x6e\x74"));}sub
 getNetStatisticsCommandForListeningTcpExtended{setNetStatisticsCommand ();if (
isNetStatisticsCommandNetstat ()){return (getCommand (
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73","\x2d\x6e\x65\x74\x6c"));
}if (isNetStatisticsCommandSs ()){return (getCommand (
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73","\x2d\x6e\x74\x6c"));}
return ($pathNotFound);}sub isNetStatisticsCommandSet{if (defined (
$netStatisticsCommand)){return ((0x1aa5+ 3047-0x268b));}return (
(0x095c+ 3339-0x1667));}sub setNetStatisticsCommandIsNotFound{Logger::warning (
"\x43\x6f\x6d\x6d\x61\x6e\x64\x20\x66\x6f\x72\x20\x6e\x65\x74\x20\x73\x74\x61\x74\x69\x73\x74\x69\x63\x73\x20\x6e\x6f\x74\x20\x66\x6f\x75\x6e\x64\x2e"
);($netStatisticsCommand=$pathNotFound);}sub setNetStatisticsCommandIsSs{(
$netStatisticsCommand=$commandSs);}sub setNetStatisticsCommandIsNetstat{(
$netStatisticsCommand=$commandNetstat);}sub isNetStatisticsCommandNetstat{if ((
$netStatisticsCommand eq $commandNetstat)){return ((0x11f1+ 1775-0x18df));}
return ((0x0cb6+ 5032-0x205e));}sub isNetStatisticsCommandSs{if ((
$netStatisticsCommand eq $commandSs)){return ((0x1b2f+ 1863-0x2275));}return (
(0x11e9+ 789-0x14fe));}sub isNetStatisticsCommandAvailable{
setNetStatisticsCommand ();if (($netStatisticsCommand eq $pathNotFound)){return 
((0x03b4+ 8252-0x23f0));}return ((0x1aea+ 1349-0x202e));}sub 
isDbusDaemonCommandAvailable{(my $dbusDaemonPath=getPath (
"\x64\x62\x75\x73\x2d\x64\x61\x65\x6d\x6f\x6e"));if (($dbusDaemonPath eq 
$pathNotFound)){return ((0x12b1+ 4744-0x2539));}return ((0x1ceb+ 1782-0x23e0));}
sub isDbusSendCommandAvailable{(my $dbusSendPath=getPath (
"\x64\x62\x75\x73\x2d\x73\x65\x6e\x64"));if (($dbusSendPath eq $pathNotFound)){
return ((0x1096+ 3705-0x1f0f));}return ((0x08a1+ 2060-0x10ac));}sub 
isNotDbusSendCommandAvailable{return ((!isDbusSendCommandAvailable ()));}sub 
getDbusSendCommand{return (getPath ("\x64\x62\x75\x73\x2d\x73\x65\x6e\x64"));}
"\x3f\x3f\x3f";
